# Generated by roxygen2: do not edit by hand

S3method(augment,logitr)
S3method(coef,logitr)
S3method(coef,summary.logitr)
S3method(confint,logitr)
S3method(fitted,logitr)
S3method(glance,logitr)
S3method(logLik,logitr)
S3method(model.frame,logitr)
S3method(model.matrix,logitr)
S3method(predict,logitr)
S3method(print,logitr)
S3method(print,logitr_validation)
S3method(print,logitr_wtp)
S3method(print,summary.logitr)
S3method(residuals,logitr)
S3method(se,logitr)
S3method(summary,logitr)
S3method(terms,logitr)
S3method(tidy,logitr)
S3method(vcov,logitr)
S3method(wtp,logitr)
export(augment)
export(ci)
export(dummyCode)
export(fquantile)
export(glance)
export(logit_probs)
export(logitr)
export(predictChoices)
export(predictProbs)
export(recodeData)
export(se)
export(simulateShares)
export(statusCodes)
export(tidy)
export(validate_data)
export(wtp)
export(wtpCompare)
importFrom(generics,augment)
importFrom(generics,glance)
importFrom(generics,tidy)
importFrom(utils,packageDescription)
